@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /* ---------------------------- included header files ---------------------- */
@@ -262,7 +261,7 @@ static int ParseBinding(
 	KeySym keysym = NoSymbol;
 	Bool is_unbind_request = False;
 	Bool is_pass_through = False;
-	Bool is_binding_removed = False;
+	Bool are_similar_bindings_left;
 	Binding *b;
 	Binding *rmlist = NULL;
 	STROKE_CODE(char stroke[STROKE_MAX_SEQUENCE + 1] = "");
@@ -477,15 +476,17 @@ static int ParseBinding(
 		}
 	}
 
-	/*
-	** strip leading whitespace from action if necessary
-	*/
-	while (*action && (*action == ' ' || *action == '\t'))
+	if (action != NULL)
 	{
-		action++;
+		action = SkipSpaces(action, NULL, 0);
 	}
-
-	if (action)
+	if (
+		action == NULL || *action == 0 ||
+		(action[0] == '-' && !is_pass_through))
+	{
+		is_unbind_request = True;
+	}
+	else
 	{
 		is_pass_through = is_pass_through_action(action);
 		if (is_pass_through)
@@ -508,11 +509,6 @@ static int ParseBinding(
 			}
 		}
 	}
-	/* see if it is an unbind request */
-	if (!action || (action[0] == '-' && !is_pass_through))
-	{
-		is_unbind_request = True;
-	}
 
 	/* short circuit menu bindings for now. */
 	if ((context & C_MENU) == C_MENU)
@@ -540,17 +536,17 @@ static int ParseBinding(
 	*/
 	/* BEGIN remove */
 	CollectBindingList(
-		dpy, pblist, &rmlist, type, STROKE_ARG((void *)stroke)
+		dpy, pblist, &rmlist, &are_similar_bindings_left, type,
+		STROKE_ARG((void *)stroke)
 		button, keysym, modifier, context, window_name);
 	if (rmlist != NULL)
 	{
-		is_binding_removed = True;
-		if (is_unbind_request)
+		int bcontext;
+
+		if (is_unbind_request && are_similar_bindings_left == False)
 		{
 			int rc = 0;
 
-			/* remove the grabs for the key for unbind
-			 * requests */
 			for (b = rmlist; b != NULL; b = b->NextBinding)
 			{
 				/* release the grab */
@@ -563,11 +559,6 @@ static int ParseBinding(
 			}
 		}
 		FreeBindingList(rmlist);
-	}
-	if (is_binding_removed)
-	{
-		int bcontext;
-
 		bcontext = bind_get_bound_button_contexts(
 			pblist, buttons_grabbed);
 		update_nr_buttons(
@@ -639,6 +630,74 @@ static void binding_cmd(F_CMD_ARGS, binding_t type)
 	return;
 }
 
+void print_bindings(void)
+{
+	Binding *b;
+
+	fprintf(stderr, "Current list of bindings:\n\n");
+	for (b = Scr.AllBindings; b != NULL; b = b->NextBinding)
+	{
+		switch (b->type)
+		{
+		case BIND_KEYPRESS:
+			fprintf(stderr, "Key");
+			break;
+		case BIND_PKEYPRESS:
+			fprintf(stderr, "PointerKey");
+			break;
+		case BIND_BUTTONPRESS:
+		case BIND_BUTTONRELEASE:
+			fprintf(stderr, "Mouse");
+			break;
+		case BIND_STROKE:
+			fprintf(stderr, "Stroke");
+			break;
+		default:
+			fvwm_msg(
+				ERR, "print_bindings",
+				"invalid binding type %d", b->type);
+			continue;
+		}
+		if (b->windowName != NULL)
+		{
+			fprintf(stderr, " (%s)", b->windowName);
+		}
+		switch (b->type)
+		{
+		case BIND_KEYPRESS:
+		case BIND_PKEYPRESS:
+			fprintf(stderr, "\t%s", b->key_name);
+			break;
+		case BIND_BUTTONPRESS:
+		case BIND_BUTTONRELEASE:
+			fprintf(stderr, "\t%d", b->Button_Key);
+			break;
+		case BIND_STROKE:
+			STROKE_CODE(
+				fprintf(
+					stderr, "\t%s\t%d",
+					(char *)b->Stroke_Seq, b->Button_Key));
+			break;
+		}
+		{
+			char *mod_string;
+			char *context_string;
+
+			mod_string = charmap_table_to_string(
+				MaskUsedModifiers(b->Modifier),key_modifiers);
+			context_string = charmap_table_to_string(
+				b->Context, win_contexts);
+			fprintf(
+				stderr, "\t%s\t%s\t%s\n", context_string,
+				mod_string, (char *)b->Action);
+			free(mod_string);
+			free(context_string);
+		}
+	}
+
+	return;
+}
+
 /* ---------------------------- interface functions ------------------------ */
 
 /* Removes all unused modifiers from in_modifiers */
