@@ -10,18 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
-/* This module is all new
- * by Rob Nation
- *
- * This code handles colormaps for fvwm.
- *
- * Copyright 1994 Robert Nation. No restrictions are placed on this code,
- * as long as the copyright notice is preserved . No guarantees or
- * warrantees of any sort whatsoever are given or implied or anything.
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /* ---------------------------- included header files ---------------------- */
@@ -352,7 +341,7 @@ void FetchWmColormapWindows (FvwmWindow *fw)
 {
 	XWindowAttributes getattribs;
 	XSetWindowAttributes setattribs;
-	long int i;
+	long i;
 	unsigned long valuemask;
 
 	if (fw->cmap_windows != (Window *)NULL)
@@ -394,7 +383,7 @@ void FetchWmColormapWindows (FvwmWindow *fw)
 void EnterSubWindowColormap(Window win)
 {
 	FvwmWindow         *t;
-	long int            i;
+	long                i;
 	XWindowAttributes   attribs;
 
 	for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
@@ -424,7 +413,7 @@ void EnterSubWindowColormap(Window win)
 void LeaveSubWindowColormap(Window win)
 {
 	FvwmWindow *t;
-	long int i;
+	long i;
 	int bWinInList, bParentInList;
 
 	for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
