@@ -10,16 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
-/*
- *
- * This is all original code by Robert Nation
- * which reads motif mwm window manager
- * hints from a window, and makes necessary adjustments for fvwm.
- *
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /* ---------------------------- included header files ---------------------- */
@@ -28,19 +19,22 @@
 
 #include <stdio.h>
 #include <X11/Xproto.h>
+#include <X11/Xatom.h>
 
 #include "libs/fvwmlib.h"
 #include "libs/FShape.h"
+#include "libs/Parse.h"
+#include "libs/lang-strings.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "execcontext.h"
 #include "commands.h"
 #include "misc.h"
 #include "screen.h"
-#include "lang-strings.h"
 #include "update.h"
 #include "style.h"
 #include "geometry.h"
+#include "decorations.h"
 
 /* ---------------------------- local definitions -------------------------- */
 
@@ -201,7 +195,7 @@ void GetOlHints(FvwmWindow *t)
 			}
 
 			/* got this from olvwm and sort of mapped it to
-			 * FVWM/MWM hints */
+			 * fvwm/MWM hints */
 			if (win_type == _XA_OL_WT_BASE)
 			{
 				t->ol_hints = OL_DECOR_ALL;
@@ -614,8 +608,8 @@ void SelectDecor(FvwmWindow *t, window_style *pstyle, short *buttons)
 	return;
 }
 
-static Bool __is_resize_allowed(const FvwmWindow *t, int functions,
-				Bool is_user_request)
+static Bool __is_resize_allowed(
+	const FvwmWindow *t, int functions, request_origin_t request_origin)
 {
         if (!HAS_OVERRIDE_SIZE_HINTS(t) &&
 	    t->hints.min_width == t->hints.max_width &&
@@ -623,18 +617,19 @@ static Bool __is_resize_allowed(const FvwmWindow *t, int functions,
 	{
 	        return False;
 	}
-	if (is_user_request && IS_SIZE_FIXED(t))
+	if (request_origin && IS_SIZE_FIXED(t))
 	{
 	        return False;
 	}
-	else if (!is_user_request && IS_PSIZE_FIXED(t))
+	else if (!request_origin && IS_PSIZE_FIXED(t))
 	{
 	        return False;
 	}
-	if (is_user_request && !(functions & MWM_FUNC_RESIZE))
+	if (request_origin && !(functions & MWM_FUNC_RESIZE))
 	{
 	        return False;
 	}
+
 	return True;
 }
 
@@ -645,7 +640,7 @@ static Bool __is_resize_allowed(const FvwmWindow *t, int functions,
 */
 Bool is_function_allowed(
 	int function, char *action_string, const FvwmWindow *t,
-	Bool is_user_request, Bool do_allow_override_mwm_hints)
+	request_origin_t request_origin, Bool do_allow_override_mwm_hints)
 {
 	unsigned int functions;
 	char *functionlist[] = {
@@ -772,7 +767,7 @@ Bool is_function_allowed(
 		}
 		break;
 	case F_RESIZE:
-	        if(!__is_resize_allowed(t,functions,is_user_request))
+	        if(!__is_resize_allowed(t, functions, request_origin))
 		{
 		        return False;
 		}
@@ -786,11 +781,11 @@ Bool is_function_allowed(
 		break;
 	case F_MAXIMIZE:
 	        if (IS_MAXIMIZE_FIXED_SIZE_DISALLOWED(t) &&
-		    !__is_resize_allowed(t,functions,is_user_request))
+		    !__is_resize_allowed(t, functions, request_origin))
 		{
 		       return False;
 		}
-		if ((is_user_request && !(functions & MWM_FUNC_MAXIMIZE)) ||
+		if ((request_origin && !(functions & MWM_FUNC_MAXIMIZE)) ||
 		    IS_UNMAXIMIZABLE(t))
 		{
 			return False;
@@ -799,15 +794,15 @@ Bool is_function_allowed(
 	case F_MOVE:
 		/* Move is a funny hint. Keeps it out of the menu, but you're
 		 * still allowed to move. */
-		if (is_user_request && IS_FIXED(t))
+		if (request_origin && IS_FIXED(t))
 		{
 			return False;
 		}
-		else if (!is_user_request && IS_FIXED_PPOS(t))
+		else if (!request_origin && IS_FIXED_PPOS(t))
 		{
 			return False;
 		}
-		if (is_user_request && !(functions & MWM_FUNC_MOVE))
+		if (request_origin && !(functions & MWM_FUNC_MOVE))
 		{
 			return False;
 		}
