@@ -11,8 +11,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 #include "config.h"
@@ -23,6 +22,8 @@
 #include <X11/Xmd.h>
 
 #include "libs/fvwmlib.h"
+#include "libs/Parse.h"
+#include "libs/Strings.h"
 #include "fvwm.h"
 #include "cursor.h"
 #include "functions.h"
@@ -152,8 +153,8 @@ void CMD_EwmhBaseStruts(F_CMD_ARGS)
 		ewmhc.BaseStrut.right  = val[1];
 		ewmhc.BaseStrut.top    = val[2];
 		ewmhc.BaseStrut.bottom = val[3];
-		ewmh_ComputeAndSetWorkArea();
-		ewmh_HandleDynamicWorkArea();
+
+		EWMH_UpdateWorkArea();
 	}
 }
 /*
