@@ -81,10 +81,8 @@
 struct size_borders;
 struct exec_context_t;
 
-#ifdef USEDECOR
 /* definition in screen.h */
 struct FvwmDecor;
-#endif
 
 /* ---------------------------- type definitions --------------------------- */
 
@@ -217,7 +215,6 @@ typedef struct
 		unsigned do_ewmh_use_stacking_hints : 1;
 		unsigned do_ewmh_ignore_window_type : 1;
 		unsigned do_iconify_window_groups : 1;
-		unsigned do_ignore_gnome_hints : 1;
 		unsigned do_ignore_icon_boxes : 1;
 		unsigned do_ignore_restack : 1;
 		unsigned do_use_window_group_hint : 1;
@@ -439,6 +436,8 @@ typedef struct WindowConditionMask
 	{
 		unsigned do_accept_focus : 1;
 		unsigned do_check_desk : 1;
+		unsigned do_check_screen : 1;
+		unsigned do_check_cond_desk : 1;
 		unsigned do_check_desk_and_global_page : 1;
 		unsigned do_check_desk_and_page : 1;
 		unsigned do_check_global_page : 1;
@@ -466,6 +465,8 @@ typedef struct WindowConditionMask
 	window_flags flag_mask;
 	struct name_condition *name_condition;
 	int layer;
+	int desk;
+	int screen;
 	int placed_by_button_mask;
 	int placed_by_button_set_mask;
 } WindowConditionMask;
@@ -597,6 +598,8 @@ typedef struct style_flags
 	unsigned has_placement_percentage_penalty : 1;
 	unsigned has_placement_position_string : 1;
 	unsigned has_initial_map_command_string : 1;
+	unsigned has_title_format_string : 1;
+	unsigned has_icon_title_format_string : 1;
 } style_flags;
 
 typedef struct style_id_t
@@ -641,9 +644,7 @@ typedef struct window_style
 #endif
 	char *icon_name;
 	char *mini_icon_name;
-#ifdef USEDECOR
 	char *decor_name;
-#endif
 	unsigned char min_icon_width;
 	unsigned char max_icon_width;
 	unsigned char min_icon_height;
@@ -699,11 +700,15 @@ typedef struct window_style
 	pl_percent_penalty_struct pl_percent_penalty;
 	char *pl_position_string;
 	char *initial_map_command_string;
+	char *title_format_string;
+	char *icon_title_format_string;
 	style_flags flags;
 	style_flags flag_default;
 	style_flags flag_mask;
 	style_flags change_mask;
 	unsigned has_style_changed : 1;
+	unsigned has_title_format_string : 1;
+	unsigned has_icon_title_format_string : 1;
 } window_style;
 
 typedef struct window_g
@@ -784,9 +789,7 @@ typedef struct FvwmWindow
 	int nr_right_buttons;
 #define BUTTON_INDEX(b) \
 	(((b) == 0) ? (NUMBER_OF_TITLE_BUTTONS - 1) : ((b) - 1))
-#ifdef USEDECOR
 	struct FvwmDecor *decor;
-#endif
 	/* is this a shaped window */
 	int wShaped;
 	Pixmap title_background_pixmap;
@@ -942,6 +945,7 @@ typedef struct FvwmWindow
 #define EWMH_WINDOW_TYPE_MENU_ID      4
 #define EWMH_WINDOW_TYPE_NORMAL_ID    5
 #define EWMH_WINDOW_TYPE_TOOLBAR_ID   6
+#define EWMH_WINDOW_TYPE_NOTIFICATION_ID 7
 	/* Note: if the type of this variable is changed, do update the
 	 * CONFIGARGSNEW macro in module_interface.c, libs/vpacket.h and too!
 	 */
