@@ -15,7 +15,7 @@ void AnimatedMoveFvwmWindow(
 	Bool fWarpPointerToo, int cmsDelay, float *ppctMovement);
 Bool __move_loop(
 	const exec_context_t *exc, int XOffset, int YOffset, int Width,
-	int Height, int *FinalX, int *FinalY,Bool do_move_opaque);
+	int Height, int *FinalX, int *FinalY, Bool do_move_opaque, int cursor);
 int is_window_sticky_across_pages(FvwmWindow *fw);
 int is_window_sticky_across_desks(FvwmWindow *fw);
 void handle_stick(
@@ -26,5 +26,8 @@ void __move_icon(
 	FvwmWindow *fw, int x, int y, int old_x, int old_y,
 	Bool do_move_animated, Bool do_warp_pointer);
 int placement_binding(int button,KeySym keysym,int modifier,char *action);
+int GetMoveArguments(
+	char **paction, int w, int h, int *pFinalX, int *pFinalY,
+	Bool *fWarp, Bool *fPointer, Bool fKeep);
 
 #endif /* _MOVE_RESIZE_ */
