@@ -281,9 +281,7 @@ typedef struct
 
 typedef struct FvwmDecor
 {
-#ifdef USEDECOR
 	char *tag;                    /* general style tag */
-#endif
 	int title_height;           /* explicitly specified title bar height */
 	int min_title_height;
 	/* titlebar buttons */
@@ -293,9 +291,7 @@ typedef struct FvwmDecor
 	{
 		DecorFace active, inactive;
 	} BorderStyle;
-#ifdef USEDECOR
 	struct FvwmDecor *next;       /* additional user-defined styles */
-#endif
 	struct
 	{
 		unsigned has_changed : 1;
@@ -432,7 +428,9 @@ typedef struct ScreenInfo
 	/* The window that the UnknownWinFocused window stole the focus from.
 	 */
 	Window StolenFocusWin;
+	FvwmWindow *StolenFocusFvwmWin;
 	FvwmWindow *focus_in_pending_window;
+	FvwmWindow *focus_in_requested_window;
 	/* #pixels to scroll on screen edge */
 	int EdgeScrollX;
 	/* #pixels to scroll on screen edge */
@@ -477,6 +475,7 @@ typedef struct ScreenInfo
 		unsigned do_display_new_window_names : 1;
 		unsigned do_enable_ewmh_iconic_state_workaround : 1;
 		unsigned do_enable_flickering_qt_dialogs_workaround : 1;
+		unsigned do_enable_qt_drag_n_drop_workaround : 1;
 		unsigned do_explain_window_placement : 1;
 		unsigned do_install_root_cmap : 1;
 		unsigned do_raise_over_unmanaged : 1;
@@ -536,11 +535,7 @@ typedef struct ScreenInfo
 /* Macro which gets specific decor or default decor.
  * This saves an indirection in case you don't want
  * the UseDecor mechanism. */
-#ifdef USEDECOR
 #define GetDecor(window,part) ((window)->decor->part)
-#else
-#define GetDecor(window,part) (Scr.DefaultDecor.part)
-#endif
 
 /* some protos for the decoration structures */
 void LoadDefaultButton(DecorFace *bf, int i);
