@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /* ---------------------------- included header files ---------------------- */
@@ -184,7 +183,7 @@ static void apply_window_updates(
 	}
 	if (flags->do_update_visible_window_name)
 	{
-		setup_visible_name(t, False);
+		setup_visible_names(t, 4);
 		BroadcastName(M_VISIBLE_NAME,FW_W(t),FW_W_FRAME(t),
 			      (unsigned long)t,t->visible_name);
 		EWMH_SetVisibleName(t, False);
@@ -192,7 +191,7 @@ static void apply_window_updates(
 
 	if (flags->do_update_visible_icon_name)
 	{
-		setup_visible_name(t, True);
+		setup_visible_names(t, 8);
 		BroadcastName(MX_VISIBLE_ICON_NAME,FW_W(t),FW_W_FRAME(t),
 			      (unsigned long)t,t->visible_icon_name);
 		EWMH_SetVisibleName(t, True);
