@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /*
  * Around 12/20/99 we did the 3rd rewrite of the shadow/hilite stuff.
  * (That I know about (dje).
@@ -21,9 +22,8 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
+ * License along with this library; if not, see:
+ * <http://www.gnu.org/licenses/>
  *
  * The routine at the bottom "pixel_to_color_string" was not from Lesstif.
  *
@@ -35,9 +35,11 @@
 #include <stdio.h>
 #include <X11/Xproto.h>                 /* for X functions in general */
 #include "fvwmlib.h"                    /* prototype GetShadow GetHilit */
+#include "Parse.h"
 #include "Colorset.h"
 #include "PictureBase.h"
 #include "PictureUtils.h"
+#include "ColorUtils.h"
 
 #define PCT_BRIGHTNESS                  (6 * 0xffff / 100)
 
@@ -547,3 +549,37 @@ Pixel fvwmlib_clone_color(Pixel p)
 	return c.pixel;
 }
 
+/* Free an array of colours (n colours), never free black */
+void fvwmlib_free_colors(Display *dpy, Pixel *pixels, int n, Bool no_limit)
+{
+	int i;
+
+	/* We don't ever free black - dirty hack to allow freeing colours at
+	 * all */
+	/* olicha: ???? */
+	for (i = 0; i < n; i++)
+	{
+		if (pixels[i] != 0)
+		{
+			PictureFreeColors(
+				dpy, Pcmap, pixels + i, 1, 0, no_limit);
+		}
+	}
+
+	return;
+}
+
+/* Copy one color and reallocate it */
+void fvwmlib_copy_color(
+	Display *dpy, Pixel *dst_color, Pixel *src_color, Bool do_free_dest,
+	Bool do_copy_src)
+{
+	if (do_free_dest)
+	{
+		fvwmlib_free_colors(dpy, dst_color, 1, True);
+	}
+	if (do_copy_src)
+	{
+		*dst_color = fvwmlib_clone_color(*src_color);
+	}
+}
