@@ -11,8 +11,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 /* FlocaleRotateDrawString is strongly inspired by some part of xvertext
  * taken from wmx */
@@ -433,6 +432,8 @@ char *FlocaleEncodeString(
 	const char *bidi_charset;
 
 	len1 = len;
+	len2 = 0;
+
 	if (is_rtl != NULL)
 		*is_rtl = False;
 	*do_free = False;
@@ -2356,7 +2357,14 @@ void FlocaleFreeNameProperty(FlocaleNameString *ptext)
 		XFreeStringList(ptext->name_list);
 		ptext->name_list = NULL;
 	}
-	else if (ptext->name != NULL)
+	else if (ptext->name != NULL
+                 /* Sorry, this is pretty ugly.
+                    in fvwm/events.c we have:
+                    FlocaleNameString new_name = { NoName, NULL };
+                    NoName is a global extern I don't want to add to
+                    to this libary module.
+                    So, this check comes close enough: */
+                 && strcmp("Untitled",ptext->name) != 0)
 	{
 		XFree(ptext->name);
 	}
