@@ -10,34 +10,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
-/*
- * This module is all original code
- * by Rob Nation
- * Copyright 1993, Robert Nation
- *     You may use this code for any purpose, as long as the original
- *     copyright remains in the source code and all documentation
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 /*
   Changed 02/12/97 by Dan Espen:
   - added routines to determine color closeness, for color use reduction.
   Some of the logic comes from pixy2, so the copyright is below.
 */
-/*
- * Copyright 1996, Romano Giannetti. No guarantees or warantees or anything
- * are provided or implied in any way whatsoever. Use this program at your
- * own risk. Permission to use this program for any purpose is given,
- * as long as the copyright is kept intact.
- *
- * Romano Giannetti - Dipartimento di Ingegneria dell'Informazione
- *                    via Diotisalvi, 2  PISA
- * mailto:romano@iet.unipi.it
- * http://www.iet.unipi.it/~romano
- *
- */
 
 /*
  *
@@ -59,9 +38,11 @@
 #include <X11/Intrinsic.h>
 
 #include "fvwmlib.h"
+#include "System.h"
 #include "Colorset.h"
 #include "Picture.h"
 #include "PictureUtils.h"
+#include "Fsvg.h"
 
 static FvwmPicture *FvwmPictureList=NULL;
 
@@ -109,6 +90,7 @@ FvwmPicture *PCacheFvwmPicture(
 	FvwmPictureAttributes fpa)
 {
 	char *path;
+	char *real_path;
 	FvwmPicture *p = FvwmPictureList;
 
 	/* First find the full pathname */
@@ -116,6 +98,16 @@ FvwmPicture *PCacheFvwmPicture(
 	{
 		return NULL;
 	}
+        /* Remove any svg rendering options from real_path */
+	if (USE_SVG && *path == ':' &&
+	    (real_path = strchr(path + 1, ':')))
+	{
+		real_path++;
+	}
+	else
+	{
+		real_path = path;
+	}
 
 	/* See if the picture is already cached */
 	while (p)
@@ -131,8 +123,8 @@ FvwmPicture *PCacheFvwmPicture(
 		}
 
 		/* If we have found a picture with the wanted name and stamp */
-		if (!*p1 && !*p2 && !isFileStampChanged(&p->stamp, p->name) &&
-		    PICTURE_FPA_AGREE(p,fpa))
+		if (!*p1 && !*p2 && !isFileStampChanged(&p->stamp, real_path)
+		    && PICTURE_FPA_AGREE(p,fpa))
 		{
 			p->count++; /* Put another weight on the picture */
 			free(path);
@@ -288,3 +280,43 @@ FvwmPicture *PCloneFvwmPicture(FvwmPicture *pic)
 	return pic;
 }
 
+void PicturePrintImageCache(int verbose)
+{
+	FvwmPicture *p;
+	unsigned int count = 0;
+	unsigned int hits = 0;
+	unsigned int num_alpha = 0;
+	unsigned int num_mask = 0;
+
+	fflush(stderr);
+	fflush(stdout);
+	fprintf(stderr, "fvwm info on Image cache:\n");
+
+	for (p = FvwmPictureList; p != NULL; p = p->next)
+	{
+		int num_pixmaps = 1;
+		if (p->mask != None)
+		{
+			num_mask++;
+			num_pixmaps++;
+		}
+		if (p->alpha != None)
+		{
+			num_alpha++;
+			num_pixmaps++;
+		}
+		if (verbose > 0)
+		{
+			fprintf(stderr,
+				"Image: %s (%d pixmaps; used %d times)\n",
+				p->name, num_pixmaps, p->count);
+		}
+		count++;
+		hits += p->count-1;
+	}
+
+	fprintf(stderr, "%u images in cache (%d reuses) "
+		"(%u masks, %u alpha channels => %u pixmaps)\n",
+		count, hits, num_mask, num_alpha, count + num_mask + num_alpha);
+	fflush(stderr);
+}
