@@ -1,31 +1,4 @@
 /* -*-c-*- */
-/* FvwmBacker Module for Fvwm.
- *
- *  Copyright 1994,  Mike Finger (mfinger@mermaid.micro.umn.edu or
- *                               Mike_Finger@atk.com)
- *
- * The author makes not guarantees or warantees, either express or
- * implied.  Feel free to use any contained here for any purpose, as long
- * and this and any other applicible copyrights are kept intact.
-
- * The functions in this source file that are based on part of the FvwmIdent
- * module for Fvwm are noted by a small copyright atop that function, all others
- * are copyrighted by Mike Finger.  For those functions modified/used, here is
- *  the full, origonal copyright:
- *
- * Copyright 1994, Robert Nation and Nobutaka Suzuki.
- * No guarantees or warantees or anything
- * are provided or implied in any way whatsoever. Use this program at your
- * own risk. Permission to use this program for any purpose is given,
- * as long as the copyright is kept intact. */
-
-/* Modified to directly manipulate the X server if a solid color
- * background is requested. To use this, use "-solid <color_name>"
- * as the command to be executed.
- *
- * A. Davison
- * Septmber 1994.
- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -37,8 +10,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
+ */
+
+/* Modified to directly manipulate the X server if a solid color
+ * background is requested. To use this, use "-solid <color_name>"
+ * as the command to be executed.
+ *
+ * A. Davison
+ * Septmber 1994.
  */
 
 #include "config.h"
@@ -54,6 +34,7 @@
 
 #include <X11/Xlib.h>
 #include <X11/Intrinsic.h>
+#include <X11/Xatom.h>
 
 #include "libs/FShape.h"
 #include "libs/Module.h"
@@ -61,11 +42,13 @@
 #include "libs/Parse.h"
 #include "libs/PictureBase.h"
 #include "libs/FRenderInit.h"
+#include "libs/Graphics.h"
+#include "libs/XError.h"
 #include "FvwmBacker.h"
 
 /* migo (22-Nov-1999): Temporarily until fvwm_msg is moved to libs */
 #define ERR
-#define fvwm_msg(t,l,f) fprintf(stderr, "[FVWM][FvwmBacker]: <<ERROR>> %s\n", f)
+#define fvwm_msg(t,l,f) fprintf(stderr, "[fvwm][FvwmBacker]: <<ERROR>> %s\n", f)
 
 unsigned long BackerGetColor(char *color);
 
@@ -112,7 +95,7 @@ int current_x = 0;
 int current_y = 0;
 int current_colorset = -1;  /* the last matched command colorset or -1 */
 
-int Fvwm_fd[2];
+int fvwm_fd[2];
 
 char *Module;        /* i.e. "FvwmBacker" */
 char *configPrefix;  /* i.e. "*FvwmBacker" */
@@ -171,8 +154,8 @@ int main(int argc, char **argv)
 		exit(1);
 	}
 
-	Fvwm_fd[0] = atoi(argv[1]);
-	Fvwm_fd[1] = atoi(argv[2]);
+	fvwm_fd[0] = atoi(argv[1]);
+	fvwm_fd[1] = atoi(argv[2]);
 
 	/* Grab the X display information now. */
 
@@ -188,11 +171,7 @@ int main(int argc, char **argv)
 	MyDisplayHeight = DisplayHeight(dpy, screen);
 	MyDisplayWidth = DisplayWidth(dpy, screen);
 	XSetErrorHandler(ErrorHandler);
-	PictureInitCMap(dpy);
-	/* allocate default colorset */
-	AllocColorset(0);
-	FShapeInit(dpy);
-	FRenderInit(dpy);
+	flib_init_graphics(dpy);
 
 	XA_XSETROOT_ID = XInternAtom(dpy, "_XSETROOT_ID", False);
 	XA_ESETROOT_PMAP_ID = XInternAtom(dpy, "ESETROOT_PMAP_ID", False);
@@ -203,19 +182,19 @@ int main(int argc, char **argv)
 	/* Parse the config file */
 	ParseConfig();
 
-	SetMessageMask(Fvwm_fd,
+	SetMessageMask(fvwm_fd,
 		       M_NEW_PAGE | M_NEW_DESK | M_CONFIG_INFO |
 		       M_END_CONFIG_INFO | M_SENDCONFIG);
 
 	/*
 	** we really only want the current desk/page, and window list sends it
 	*/
-	SendInfo(Fvwm_fd, "Send_WindowList", 0);
+	SendInfo(fvwm_fd, "Send_WindowList", 0);
 
 	/* tell fvwm we're running */
-	SendFinishedStartupNotification(Fvwm_fd);
+	SendFinishedStartupNotification(fvwm_fd);
 
-	/* Recieve all messages from Fvwm */
+	/* Recieve all messages from fvwm */
 	EndLessLoop();
 
 	/* Should never get here! */
@@ -234,11 +213,11 @@ void EndLessLoop(void)
 }
 
 /*
-  ReadFvwmPipe - Read a single message from the pipe from Fvwm
+  ReadFvwmPipe - Read a single message from the pipe from fvwm
 */
 void ReadFvwmPipe(void)
 {
-	FvwmPacket* packet = ReadFvwmPacket(Fvwm_fd[1]);
+	FvwmPacket* packet = ReadFvwmPacket(fvwm_fd[1]);
 	if ( packet == NULL )
 	{
 		exit(0);
@@ -416,7 +395,7 @@ void SetDeskPageBackground(const Command *c)
 	default:
 		if(c->cmdStr != NULL)
 		{
-			SendFvwmPipe(Fvwm_fd, c->cmdStr, (unsigned long)0);
+			SendFvwmPipe(fvwm_fd, c->cmdStr, (unsigned long)0);
 		}
 		break;
 	}
@@ -462,7 +441,7 @@ void ExecuteMatchingCommands(int colorset, int changed)
 }
 
 /*
-  ProcessMessage - Process the message coming from Fvwm
+  ProcessMessage - Process the message coming from fvwm
 */
 void ProcessMessage(unsigned long type, unsigned long *body)
 {
@@ -562,7 +541,7 @@ int ParseConfigLine(char *line)
 /*
   ParseConfig - Parse the configuration file fvwm to us to use
 */
-void ParseConfig()
+void ParseConfig(void)
 {
 	char *line_start;
 	char *tline;
@@ -571,13 +550,13 @@ void ParseConfig()
 	strcpy(line_start, "*");
 	strcat(line_start, Module);
 
-	InitGetConfigLine(Fvwm_fd, line_start);
-	GetConfigLine(Fvwm_fd, &tline);
+	InitGetConfigLine(fvwm_fd, line_start);
+	GetConfigLine(fvwm_fd, &tline);
 
 	while(tline != (char *)0)
 	{
 		ParseConfigLine(tline);
-		GetConfigLine(Fvwm_fd, &tline);
+		GetConfigLine(fvwm_fd, &tline);
 	}
 	free(line_start);
 }
