@@ -5,12 +5,6 @@
  * This module, and the entire GoodStuff program, and the concept for
  * interfacing this module to the Window Manager, are all original work
  * by Robert Nation
- *
- * Copyright 1993, Robert Nation. No guarantees or warantees or anything
- * are provided or implied in any way whatsoever. Use this program at your
- * own risk. Permission to use this program for any purpose is given,
- * as long as the copyright is kept intact.
- *
  */
 
 /* -------------------------------- DEBUG ---------------------------------- */
@@ -63,6 +57,7 @@ typedef struct
 	unsigned b_TransBack  : 1;     /* Transparent background */
 	unsigned b_Left       : 1;     /* Button is left-aligned */
 	unsigned b_Right      : 1;     /* Button is right-aligned */
+	unsigned b_Top        : 1;     /* Button is aligned at the top */
 	unsigned b_SizeFixed  : 1;     /* User provided rows/columns may not be
 	                                  altered */
 	unsigned b_PosFixed   : 1;     /* User provided button position */
