@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 #include "config.h"
@@ -221,12 +220,17 @@ main(int argc, char **argv)
 
 	MyName = GetFileNameFromPath(argv[0]);
 
-	if (argc == 7)
+	if (argc >= 7)
 	{
-		if (strcasecmp(argv[6], "Transient")==0 ||
-			strcasecmp(argv[6], "-Transient") == 0)
+		if (strcasecmp(argv[6], "-Transient") == 0)
 		{
 			globals.transient = 1;
+			
+			/* Optionally accept an alias to use as the transient
+			 * FvwmIconMan instance.
+			 */
+			if (argv[7])
+				MyName = argv[7];
 		}
 		else
 		{
