@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 #include "config.h"
@@ -149,7 +148,7 @@ void EvtMouseMenu(struct XObj *xobj, XButtonEvent *EvtButton)
 {
   static XEvent event;
   unsigned int modif;
-  int x1,x2,y1,y2,i,oldy;
+  int x1,x2,y1,y2,i;
   Window Win1,Win2,WinPop;
   char *str;
   int x,y,hOpt,yMenu,hMenu,wMenu;
@@ -227,7 +226,6 @@ void EvtMouseMenu(struct XObj *xobj, XButtonEvent *EvtButton)
     /* Determiner l'option courante */
     y2 = y2 - y;
     x2 = x2 - x;
-    oldy = y2;
     /* calcule de xobj->value */
     if ((x2 > 0) && (x2 < wMenu) && (y2 > 0) && (y2 < hMenu))
       newvalue = y2 / hOpt+1;
