@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 #include "config.h"
@@ -116,14 +115,12 @@ void EvtMouseRadioButton(struct XObj *xobj,XButtonEvent *EvtButton)
 	static XEvent event;
 	int End=1;
 	unsigned int modif;
-	int x1,x2,y1,y2,i,j;
+	int x1,x2,y1,y2,j;
 	Window Win1,Win2;
 	Window WinBut=0;
 	int In = 0;
 
 	j=xobj->height/2+3;
-	i=(xobj->width-FlocaleTextWidth(
-		   xobj->Ffont,xobj->title,strlen(xobj->title)))/2;
 
 	while (End)
 	{
