@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /*
@@ -300,7 +299,7 @@ void ChooseFunction(struct XObj *xobj,char *type)
 	}
 	else
 	{
-		fprintf(stderr,"Item %s unknow\n",type);
+		fprintf(stderr,"Item %s unknown\n",type);
 		exit(1);
 	}
 }
